@@ -1,21 +1,19 @@
 #!/usr/bin/env python
 
 import sys
-import os
-import logging
 import multiprocessing
 from urlparse import urlparse
 from optparse import OptionParser
 from couchdbcurl.client import Server
-from pprint import pprint
-from time import sleep
 
-def pinger_callback(*args, **kwargs):
-    print 'callback:', args, kwargs
 
 
 def pinger(entry):
-    print 'pinger started with entry:', entry
+    """Worker process.
+    Will connect to entry['server'] and call entry['design_doc']/entry['view_name'] in database entry['database']
+    """
+    
+    #print 'pinger started with entry:', entry
     try:
         db = Server(entry['server'])[entry['database']]
         db.view('%s/%s' % (entry['design_doc'], entry['view_name']), limit=0).rows
@@ -26,8 +24,10 @@ def pinger(entry):
     
 
 def main():
-    
-    parser = OptionParser()
+    """
+    Entry point.
+    """
+    parser = OptionParser(usage=u"usage: %prog [options] url1 ... urlN")
     parser.add_option("-v", "--verbose", dest="verbose", action="store_true", default=False, help="Be verbose")
     parser.add_option("-p", "--threads", dest="threads", action="store", type="int", default=multiprocessing.cpu_count(), help="Threads count")
     parser.add_option("-t", "--timeout", dest="timeout", action="store", type="int", default=10, help="Threads count")
@@ -35,7 +35,10 @@ def main():
     (options, args) = parser.parse_args()
     
     entries = []
-    
+
+    if not args:
+        parser.print_help()
+        sys.exit(3)
     
     for entry in args:
         if options.verbose:
@@ -45,7 +48,7 @@ def main():
         server = '%s://%s' % (u.scheme, u.netloc)
         _server = Server(server)
         path = [s for s in u.path.lstrip('/').split('/') if s]
-        print path
+        
         
         design_doc = None
 
@@ -109,7 +112,7 @@ def main():
         
     pool = multiprocessing.Pool()
 
-    result = pool.map_async(pinger, entries, callback=pinger_callback)
+    result = pool.map_async(pinger, entries)
     
     if options.verbose:
         print 'Waiting %d seconds for all jobs done' % options.timeout
@@ -118,11 +121,9 @@ def main():
     result.wait(options.timeout)
     
     if not result.ready():
-        if options.verbose:
-            print "Terminating pool"
+        print "Timeout reached, terminating workers"
         pool.terminate()
-        if options.verbose:
-            print "Terminated"
+        print "Terminated"
         sys.exit(42)
     else:
         if result.successful():
